==> openshift-model-operatorhub-5.7.3-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1/OperatorGroupSpecFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface OperatorGroupSpecFluent<A extends io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LabelSelector getSelector();
  public io.fabric8.kubernetes.api.model.LabelSelector buildSelector();
  public A withSelector(io.fabric8.kubernetes.api.model.LabelSelector selector);
  public java.lang.Boolean hasSelector();
  public io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpecFluent.SelectorNested<A> withNewSelector();
  public io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpecFluent.SelectorNested<A> withNewSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item);
  public io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpecFluent.SelectorNested<A> editSelector();
  public io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpecFluent.SelectorNested<A> editOrNewSelector();
  public io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpecFluent.SelectorNested<A> editOrNewSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item);
  public java.lang.String getServiceAccountName();
  public A withServiceAccountName(java.lang.String serviceAccountName);
  public java.lang.Boolean hasServiceAccountName();
  
  /**
   * Method is deprecated. use withServiceAccountName instead.
   */
  @java.lang.Deprecated
  public A withNewServiceAccountName(java.lang.String arg0);
  public java.lang.Boolean getStaticProvidedAPIs();
  public A withStaticProvidedAPIs(java.lang.Boolean staticProvidedAPIs);
  public java.lang.Boolean hasStaticProvidedAPIs();
  public A addToTargetNamespaces(java.lang.Integer index,java.lang.String item);
  public A setToTargetNamespaces(java.lang.Integer index,java.lang.String item);
  public A addToTargetNamespaces(java.lang.String... items);
  public A addAllToTargetNamespaces(java.util.Collection<java.lang.String> items);
  public A removeFromTargetNamespaces(java.lang.String... items);
  public A removeAllFromTargetNamespaces(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getTargetNamespaces();
  public java.lang.String getTargetNamespace(java.lang.Integer index);
  public java.lang.String getFirstTargetNamespace();
  public java.lang.String getLastTargetNamespace();
  public java.lang.String getMatchingTargetNamespace(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingTargetNamespace(java.util.function.Predicate<java.lang.String> predicate);
  public A withTargetNamespaces(java.util.List<java.lang.String> targetNamespaces);
  public A withTargetNamespaces(java.lang.String... targetNamespaces);
  public java.lang.Boolean hasTargetNamespaces();
  public A addNewTargetNamespace(java.lang.String arg0);
  public interface SelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.LabelSelectorFluent<io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpecFluent.SelectorNested<N>>{
    public N and();
    public N endSelector();
    
  }
  
}

==> openshift-model-operatorhub-5.12.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1/OperatorGroupSpecFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface OperatorGroupSpecFluent<A extends io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LabelSelector getSelector();
  public io.fabric8.kubernetes.api.model.LabelSelector buildSelector();
  public A withSelector(io.fabric8.kubernetes.api.model.LabelSelector selector);
  public java.lang.Boolean hasSelector();
  public io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpecFluent.SelectorNested<A> withNewSelector();
  public io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpecFluent.SelectorNested<A> withNewSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item);
  public io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpecFluent.SelectorNested<A> editSelector();
  public io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpecFluent.SelectorNested<A> editOrNewSelector();
  public io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpecFluent.SelectorNested<A> editOrNewSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item);
  public java.lang.String getServiceAccountName();
  public A withServiceAccountName(java.lang.String serviceAccountName);
  public java.lang.Boolean hasServiceAccountName();
  
  /**
   * Method is deprecated. use withServiceAccountName instead.
   */
  @java.lang.Deprecated
  public A withNewServiceAccountName(java.lang.String arg0);
  public java.lang.Boolean getStaticProvidedAPIs();
  public A withStaticProvidedAPIs(java.lang.Boolean staticProvidedAPIs);
  public java.lang.Boolean hasStaticProvidedAPIs();
  public A addToTargetNamespaces(java.lang.Integer index,java.lang.String item);
  public A setToTargetNamespaces(java.lang.Integer index,java.lang.String item);
  public A addToTargetNamespaces(java.lang.String... items);
  public A addAllToTargetNamespaces(java.util.Collection<java.lang.String> items);
  public A removeFromTargetNamespaces(java.lang.String... items);
  public A removeAllFromTargetNamespaces(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getTargetNamespaces();
  public java.lang.String getTargetNamespace(java.lang.Integer index);
  public java.lang.String getFirstTargetNamespace();
  public java.lang.String getLastTargetNamespace();
  public java.lang.String getMatchingTargetNamespace(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingTargetNamespace(java.util.function.Predicate<java.lang.String> predicate);
  public A withTargetNamespaces(java.util.List<java.lang.String> targetNamespaces);
  public A withTargetNamespaces(java.lang.String... targetNamespaces);
  public java.lang.Boolean hasTargetNamespaces();
  public A addNewTargetNamespace(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface SelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.LabelSelectorFluent<io.fabric8.openshift.api.model.operatorhub.v1.OperatorGroupSpecFluent.SelectorNested<N>>{
    public N and();
    public N endSelector();
    
  }
  
}
